argcomplete: Bash tab completion for argparse
=============================================

Description
-----------

Bash tab completion for argparse

License
-------

Apache Software License

Upstream Contact
----------------

https://pypi.org/project/argcomplete/

